@@ -82,6 +82,43 @@ class Engine:
     def timeout(self):
         return self._pool.timeout
 
+    @property
+    def minsize(self):
+        return self._pool.minsize
+
+    @property
+    def maxsize(self):
+        return self._pool.maxsize
+
+    @property
+    def size(self):
+        return self._pool.size
+
+    @property
+    def freesize(self):
+        return self._pool.freesize
+
+    def close(self):
+        """Close engine.
+
+        Mark all engine connections to be closed on getting back to pool.
+        Closed engine doesn't allow to acquire new connections.
+        """
+        self._pool.close()
+
+    def terminate(self):
+        """Terminate engine.
+
+        Terminate engine pool with instantly closing all acquired
+        connections also.
+        """
+        self._pool.terminate()
+
+    @asyncio.coroutine
+    def wait_closed(self):
+        """Wait for closing all engine's connections."""
+        yield from self._pool.wait_closed()
+
     @asyncio.coroutine
     def acquire(self):
         """Get a connection from pool."""
